@@ -10,8 +10,8 @@ $scanner->tcp_connect_scan();
 $scanner->ident_check();
 $scanner->add_scan_port(80);
 $scanner->add_scan_port(25);
-$scanner->add_scan_port(161);
-$scanner->add_scan_port(162);
+$scanner->add_scan_port(22);
+$scanner->add_scan_port(21);
 $scanner->ack_icmp_ping();
 $scanner->add_target($ARGV[0] || 'localhost');
 $scanner->max_rtt_timeout(200);
@@ -21,11 +21,11 @@ $scanner->scan();
 sub found_port {
 
     shift;
-    my $name = shift;
-    my $ip   = shift;
+    my $host = shift;
     my $port = shift;
 
-    next unless $port->owner();
+    my $name = $host->name();
+    my $ip   = join(',',map {$_->address()} $host->addresses());
 
     print "$name ($ip), port ",$port->number()," owned by ",
           $port->owner(),"\n";
